@@ -22,7 +22,7 @@ def admin_override():
     """
     package_path = Path(__file__).parent
     package_image_path = Path.joinpath(package_path,
-                                       'static/images/web_dashboard_static_dashboard_publitzer-mini-logo.svg')
+                                       'static/images/publitzer_go_logo.svg')
     package_base_path = Path.joinpath(package_path, 'templates/base.html')
     package_admin_base_path = Path.joinpath(package_path, 'templates/admin_base.html')
     package_home_path = Path.joinpath(package_path, 'templates/home.html')
